@@ -24,20 +24,19 @@
 #include "dialog.h"
 #include "slot.h"
 
+int waiting_for_mouse_up(void) {
+  if (!press_data) return 0;
+  if (press_data->status == STATUS_IS_DRAG) return 1;
+  if (press_data->status == STATUS_SHOW) return 1;
+  return 0;
+}
+
 /* Defining SINGLE_ACTION prevents scheme from being called twice when
  * a double click occurs but delays the single_click action by 250ms */
 /*#define SINGLE_ACTION */
 /* I don't like this, so it's commented out -jrb */
 
 /* Button press statuses */
-enum {
-  STATUS_NONE,
-  STATUS_MAYBE_DRAG,
-  STATUS_NOT_DRAG,
-  STATUS_IS_DRAG,
-  STATUS_CLICK,
-  STATUS_SHOW
-};
 
 void end_of_game_test() {
 
@@ -130,9 +129,12 @@ gint button_press_event (GtkWidget *widget, GdkEventButton *event, void *d)
   /* ignore the gdk synthetic click events */
   if (event->type != GDK_BUTTON_PRESS)
     return TRUE;
-  if (event->button == 2)
-    return TRUE;
   
+  if ((event->button == 2) || 
+      (event->button == 3 && (press_data->status == STATUS_IS_DRAG)) ||
+      (event->button == 1 && (press_data->status == STATUS_SHOW || press_data->status == STATUS_IS_DRAG)))
+    return TRUE;
+
 #ifndef SINGLE_ACTION
   if (gdk_time_get() > first_press + dbl_click_time)
     press_data->status = STATUS_NONE;
@@ -202,11 +204,13 @@ gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
 
   switch (press_data->status) {
   case STATUS_IS_DRAG:
+    if (event->button != 1) return TRUE;
     press_data->status = STATUS_NONE;
     drop_moving_cards(event->x, event->y);
     break;
     
   case STATUS_SHOW:
+    if (event->button != 3) return TRUE;
     press_data->status = STATUS_NONE;
     gdk_window_hide(press_data->moving_cards);
     press_data->moving_pixmap = NULL;
@@ -215,6 +219,7 @@ gint button_release_event (GtkWidget *widget, GdkEventButton *event, void *d)
     
   case STATUS_MAYBE_DRAG:
   case STATUS_NOT_DRAG:
+    if (event->button != 1) return TRUE;
     press_data->status = STATUS_CLICK;
 #ifndef SINGLE_ACTION
     gh_call2 (gh_eval_str ("record-move"), gh_long2scm (-1),
