@@ -19,6 +19,10 @@
 
 #include <config.h>
 
+#ifdef HAVE_ALLOCA_H
+#include <alloca.h>
+#endif
+
 #include <sys/types.h>
 #include <string.h>
 #include <stdlib.h>
@@ -344,6 +348,7 @@ void create_press_data ()
   press_data = malloc(sizeof(press_data_type));
   press_data->moving_cards = gdk_window_new(playing_area->window, &attributes,
 					    (GDK_WA_VISUAL | GDK_WA_COLORMAP));
+  press_data->status = 0;
 }
 
 gchar* start_game;
@@ -444,7 +449,7 @@ retrieve_state (GnomeClient *client)
 }
 
 int
-is_game (struct dirent* dent)
+is_game (const struct dirent* dent)
 {
   return (!strcmp (g_extension_pointer (dent->d_name),"scm") &&
 	  strcmp (dent->d_name,"sol.scm"));
@@ -454,13 +459,16 @@ int main (int argc, char *argv [])
 {
   gchar* variation = "";
   struct poptOption aisleriot_opts[] = {
-    {"variation", '\0', POPT_ARG_STRING, &variation, 0,
-     N_("Variation on game rules"), N_("NAME")},
-    {NULL, '\0', 0, NULL}
+    {"variation", '\0', POPT_ARG_STRING, NULL, 0, NULL, NULL},
+    {NULL, '\0', 0, NULL, 0, NULL, NULL}
   };
   gint i;
   gchar* dir;
 
+  aisleriot_opts[0].arg = &variation;
+  aisleriot_opts[0].descrip = N_("Variation on game rules");
+  aisleriot_opts[0].argDescrip = N_("NAME");
+
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
   textdomain (PACKAGE);
 
