@@ -1154,6 +1154,8 @@ to_destination_auto(void)
 
   if (freecellgame_is_there_no_way(freecellgame))
     {
+      freecellgame_delete_history(freecellgame);
+
       mb = gnome_message_box_new (_("Sorry, there are no more valid moves."),
 				  GNOME_MESSAGE_BOX_INFO,
 				  GNOME_STOCK_BUTTON_OK,
@@ -1169,8 +1171,8 @@ to_destination_auto(void)
   
   if (freecellgame_is_finished(freecellgame))
     {
-      g_slist_free (freecellgame->history);
-      freecellgame->history = NULL;
+      freecellgame_delete_history(freecellgame);
+
       mb = gnome_message_box_new (_("Congratulations.  You won.\nDo you want to play again?"),
 				  GNOME_MESSAGE_BOX_QUESTION,
 				  GNOME_STOCK_BUTTON_YES,
