@@ -1,3 +1,22 @@
+/* 
+ *   Gnome Nibbles: Gnome Worm Game
+ *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
+ * 
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the Free Software
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include <config.h>
 #include <gnome.h>
 
@@ -46,7 +65,7 @@ void gnibbles_boni_add_bonus (GnibblesBoni *boni, gint t_x, gint t_y,
 	gnibbles_bonus_draw (boni->bonuses[boni->numbonuses]);
 	boni->numbonuses++;
 	if (t_type != BONUSREGULAR)
-		gnome_triggers_do (NULL, NULL, "gnibbles", "appear", NULL);
+		gnibbles_play_sound ("appear");
 }
 
 int gnibbles_boni_fake (GnibblesBoni *boni, gint x, gint y)
