@@ -1,3 +1,22 @@
+/* 
+ *   Gnome Nibbles: Gnome Worm Game
+ *   Written by Sean MacIsaac <sjm@acm.org>, Ian Peters <itp@gnu.org>
+ * 
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the Free Software
+ *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include "worm.h"
 #include "gnibbles.h"
 #include "boni.h"
@@ -14,20 +33,15 @@ extern GnibblesProperties *properties;
 
 extern gint current_level;
 
-GnibblesWorm *gnibbles_worm_new (gint8 t_pixmap, guint t_up, guint t_down,
-		guint t_left, guint t_right)
+GnibblesWorm *gnibbles_worm_new (guint t_number)
 {
         GnibblesWorm *tmp = (GnibblesWorm *) malloc (sizeof (GnibblesWorm));
 
-        tmp->pixmap = t_pixmap;
-	tmp->up = t_up;
-	tmp->down = t_down;
-	tmp->left = t_left;
-	tmp->right = t_right;
 	tmp->xoff = (gint8 *) malloc (CAPACITY * sizeof (gint8));
 	tmp->yoff = (gint8 *) malloc (CAPACITY * sizeof (gint8));
 	tmp->lives = SLIVES;
 	tmp->score = 0;
+	tmp->number = t_number;
 
         return tmp;
 }
@@ -61,21 +75,36 @@ void gnibbles_worm_handle_keypress (GnibblesWorm *worm, guint keyval)
 	if (worm->keypress)
 		return;
 	
-	if ((keyval == worm->up) && (worm->direction != WORMDOWN)) {
-		worm->direction = WORMUP;
-		worm->keypress = 1;
-	}
-	if ((keyval == worm->right) && (worm->direction !=WORMLEFT)) {
-		worm->direction = WORMRIGHT;
-		worm->keypress = 1;
-	}
-	if ((keyval == worm->down) && (worm->direction != WORMUP)) {
-		worm->direction = WORMDOWN;
-		worm->keypress = 1;
-	}
-	if ((keyval == worm->left) && (worm->direction != WORMRIGHT)) {
-		worm->direction = WORMLEFT;
-		worm->keypress = 1;
+	if (properties->wormprops[worm->number]->relmove) {
+		if (keyval == properties->wormprops[worm->number]->left)
+			worm->direction = worm->direction - 1;
+		if (keyval == properties->wormprops[worm->number]->right)
+			worm->direction = worm->direction + 1;
+		if (worm->direction == 0)
+			worm->direction = 4;
+		if (worm->direction == 5)
+			worm->direction = 1;
+	} else {
+		if ((keyval == properties->wormprops[worm->number]->up) &&
+				(worm->direction != WORMDOWN)) {
+			worm->direction = WORMUP;
+			worm->keypress = 1;
+		}
+		if ((keyval == properties->wormprops[worm->number]->right) &&
+				(worm->direction !=WORMLEFT)) {
+			worm->direction = WORMRIGHT;
+			worm->keypress = 1;
+		}
+		if ((keyval == properties->wormprops[worm->number]->down) &&
+				(worm->direction != WORMUP)) {
+			worm->direction = WORMDOWN;
+			worm->keypress = 1;
+		}
+		if ((keyval == properties->wormprops[worm->number]->left) &&
+				(worm->direction != WORMRIGHT)) {
+			worm->direction = WORMLEFT;
+			worm->keypress = 1;
+		}
 	}
 }
 
@@ -126,7 +155,7 @@ static void gnibbles_worm_grok_bonus (GnibblesWorm *worm)
 
 	if (gnibbles_boni_fake (boni, worm->xhead, worm->yhead)) {
 		gtk_timeout_add(1, (GtkFunction) gnibbles_worm_reverse, worm);
-		gnome_triggers_do (NULL, NULL, "gnibbles", "reverse", NULL);
+		gnibbles_play_sound ("reverse");
 		return;
 	}
 
@@ -136,15 +165,13 @@ static void gnibbles_worm_grok_bonus (GnibblesWorm *worm)
 			worm->change += (NUMBONI - boni->numleft) * GROWFACTOR;
 			worm->score += (NUMBONI - boni->numleft) *
 				current_level;
-			gnome_triggers_do (NULL, NULL, "gnibbles", "gobble",
-					NULL);
+			gnibbles_play_sound ("gobble");
 			break;
 		case BONUSDOUBLE:
 			worm->score += (worm->length + worm->change) *
 				current_level;
 			worm->change += worm->length + worm->change;
-			gnome_triggers_do (NULL, NULL, "gnibbles", "bonus",
-					NULL);
+			gnibbles_play_sound ("bonus");
 			break;
 		case BONUSHALF:
 			if (worm->length + worm->change > 2) {
@@ -152,14 +179,12 @@ static void gnibbles_worm_grok_bonus (GnibblesWorm *worm)
 					2) * current_level;
 				worm->change -= (worm->length + worm->change) /
 					2;
-				gnome_triggers_do (NULL, NULL, "gnibbles",
-						"bonus", NULL);
+				gnibbles_play_sound ("bonus");
 			}
 			break;
 		case BONUSLIFE:
 			worm->lives += 1;
-			gnome_triggers_do (NULL, NULL, "gnibbles", "life",
-					NULL);
+			gnibbles_play_sound ("life");
 			break;
 		case BONUSREVERSE:
 			for (i = 0; i < properties->numworms; i++)
@@ -167,8 +192,7 @@ static void gnibbles_worm_grok_bonus (GnibblesWorm *worm)
 					gtk_timeout_add(1, (GtkFunction)
 							gnibbles_worm_reverse,
 						 	worms[i]);
-			gnome_triggers_do (NULL, NULL, "gnibbles", "reverse",
-					NULL);
+			gnibbles_play_sound ("reverse");
 			break;
 	}
 }
@@ -234,7 +258,7 @@ void gnibbles_worm_draw_head (GnibblesWorm *worm)
 
 	if (board[worm->xhead][worm->yhead] == WARPLETTER) {
 		gnibbles_warpmanager_worm_change_pos (warpmanager, worm);
-		gnome_triggers_do (NULL, NULL, "gnibbles", "teleport", NULL);
+		gnibbles_play_sound ("teleport");
 	}
 
 	worm->start++;
@@ -244,7 +268,8 @@ void gnibbles_worm_draw_head (GnibblesWorm *worm)
 		
 	board[worm->xhead][worm->yhead] = WORMCHAR;
 
-	gnibbles_draw_pixmap (worm->pixmap, worm->xhead, worm->yhead);
+	gnibbles_draw_pixmap (properties->wormprops[worm->number]->color,
+			worm->xhead, worm->yhead);
 }
 
 gint gnibbles_worm_test_move_head(GnibblesWorm *worm)
