@@ -1,6 +1,6 @@
 /* gnome-stones - main.c
  *
- * Time-stamp: <1999/02/07 12:11:01 carsten>
+ * Time-stamp: <1999/03/03 18:09:58 carsten>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -91,9 +91,10 @@ static char *default_message= N_("Gnome-Stones (c) 1998 Carsten Schaar");
 /****************************************************************************/
 /* Commandline options.  */
 
-
 /* Command-line arguments understood by this module.  */
 static const struct poptOption options[] = {
+  {"game", 'g', POPT_ARG_STRING, &default_game, 0,
+   N_("Game to play"), N_("FILENAME")},
   {NULL, '\0', 0, NULL, 0}
 };
 
@@ -244,8 +245,8 @@ game_update_title (void)
       guint    height;
       GdkFont *font;
       GList   *tmp= g_list_nth (game->start_caves, start_cave);
-      
-      font= gdk_font_load ("-adobe-helvetica-bold-r-normal--24-240-75-75-p-138-iso8859-1");
+
+      font = gdk_font_ref (gstones_view->style->font);
       if (!font)
 	font= gdk_font_load ("fixed");
 
@@ -263,7 +264,7 @@ game_update_title (void)
 		       gstones_view->style->black_gc,
 		       30, GAME_ROWS*STONE_SIZE-30-height*2-height/2,
 		       game->title,
-		       strlen (game->title));
+		       strlen (_(game->title)));
       
       gdk_draw_text   (title_image,
 		       font,
